@@ -212,8 +212,8 @@ class data_process:
                 train_size[:i], 0), label=str(int(labels[i])))
         # plt.title("Data distribution of dataset")
         plt.legend()
-        # plt.title('Client-wise Non-IID Setting', fontsize = 20)
-        plt.title('Cluster-wise Non-IID Setting', fontsize = 20)
+        plt.title('Client-wise Non-IID Setting', fontsize = 20)
+        # plt.title('Cluster-wise Non-IID Setting', fontsize = 20)
         plt.xlabel('Dataset size', fontsize=16)
         plt.ylabel('Client ID', fontsize=16)
         # plt.ylim((0,len(train_splited)-1))
